PresenceUser class

Representation of a user's presence in a channel.

Constructors

PresenceUser({required String connectionId, required Map<String, dynamic> info, DateTime? joinedAt})
Creates a PresenceUser instance.
PresenceUser.fromJson(Map<String, dynamic> json)
Deserializes a PresenceUser from a JSON map.
factory

Properties

connectionId String
Unique connection ID associated with this user session.
final
hashCode int
The hash code for this object.
no setterinherited
info Map<String, dynamic>
User profile metadata (e.g. userId, username, avatar).
final
joinedAt DateTime
Timestamp when the user joined the presence channel.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes presence user data to JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited