cancel method
void
cancel()
Cancels the underlying stream subscription and stops query invalidations.
Example:
bridge.cancel();
Implementation
void cancel() {
_subscription.cancel();
}
Cancels the underlying stream subscription and stops query invalidations.
Example:
bridge.cancel();
void cancel() {
_subscription.cancel();
}