RealtimeQueryBridge class

Bridges Realtime channel broadcasts to the BloomData client query cache.

When a broadcast arrives on channel, this helper calls BloomData.invalidateQueries(key) (or custom invalidation logic), immediately causing active BloomQuery widgets and listeners tracking key to refetch in the background.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels the bridge subscription.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bind({required BloomRealtimeClient client, required String channel, required List key, bool filter(Map<String, dynamic> payload)?}) RealtimeQueryBridge
Listens to a realtime channel on client and calls BloomData.invalidateQueries with key on every received message, or when filter matches.
bindStream({required Stream<Map<String, dynamic>> stream, required List key, bool filter(Map<String, dynamic> payload)?}) RealtimeQueryBridge
Listens to an existing channel stream and calls BloomData.invalidateQueries with key on every message (or when filter returns true).